menu
pref_dessert package
documentation
pref_dessert.dart
pref_dessert.dart
dark_mode
light_mode
pref_dessert
library
Classes
DesSer
<
T
>
Abstract class for deserialization and serialization which you have to implement and then pass it to the
PreferencesRepository
JsonDesSer
<
T
>
If you want to store your classes as JSON (which is recommended), use this class and only provide implementation of two methods which converts your objects from and to map.
PreferencesRepository
<
T
>
Repository class that takes
SharedPreferences
and
DesSer<T>
and allows you to save and read your objects.
SingleElementPreferencesRepository
<
T
>
Repository that stores a single element in
SharedPreferences
.
pref_dessert package
documentation
pref_dessert.dart
pref_dessert
package
Libraries
pref_dessert
pref_dessert library